@@ -1,6 +1,3 @@
-import traceback
-
-
 class MethodNotFound(AttributeError):
     pass
 
@@ -10,24 +7,21 @@ class WaiterTimeout(Exception):
 
 
 class RemoteError(Exception):
-    def __init__(self, exc_type=None, value=None, traceback=None):
+    def __init__(self, exc_type=None, value=None):
         self.exc_type = exc_type
         self.value = value
-        self.traceback = traceback
-        message = '{} {}\n{}'.format(exc_type, value, traceback)
+        message = '{} {}'.format(exc_type, value)
         super(RemoteError, self).__init__(message)
 
 
 class RemoteErrorWrapper(object):
     def __init__(self, exc):
         self.exc = exc
-        self.traceback = traceback.format_exc()
 
     def serialize(self):
         return {
             'exc_type': self.exc.__class__.__name__,
             'value': self.exc.message,
-            'traceback': self.traceback
         }
 
     @classmethod
