@@ -4,6 +4,7 @@ from functools import partial
 
 import eventlet
 from mock import Mock
+from nameko.containers import WorkerContextBase
 
 from nameko.dependencies import DependencyFactory, InjectionProvider
 
@@ -84,3 +85,21 @@ class AnyInstanceOf(object):
 
 
 ANY_PARTIAL = AnyInstanceOf(partial)
+
+
+def worker_context_factory(*keys):
+    class CustomWorkerContext(WorkerContextBase):
+        context_keys = keys
+
+        def __init__(self, container=None, service=None, method_name=None,
+                     **kwargs):
+            container_mock = Mock()
+            container_mock.config = {}
+            super(CustomWorkerContext, self).__init__(
+                container or container_mock,
+                service or Mock(),
+                method_name or Mock(),
+                **kwargs
+            )
+
+    return CustomWorkerContext
