@@ -49,11 +49,11 @@ def test_event_handler_decorator():
     assert descr.dep_cls is EventHandler
 
 
-def test_event_dispatcher():
+def test_event_dispatcher(empty_config):
 
     container = Mock(spec=ServiceContainer)
     container.service_name = "srcservice"
-    container.config = Mock()
+    container.config = empty_config
 
     service = Mock()
     worker_ctx = WorkerContext(container, service, "dispatch")
